==> alfresco-repository-23.7.0.15-sources.jar: org/alfresco/repo/virtual/store/VirtualFolderDefinitionResolver.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.virtual.store;

import org.alfresco.repo.virtual.VirtualizationException;
import org.alfresco.repo.virtual.ref.Reference;
import org.alfresco.repo.virtual.template.VirtualFolderDefinition;

/**
 * A {@link Reference} based {@link VirtualFolderDefinition} resolver.<br>
 *
 * @author Bogdan Horje
 */
public interface VirtualFolderDefinitionResolver
{
    /**
     * @param reference
     * @return the {@link VirtualFolderDefinition} of the given
     *         {@link Reference} considering inner paths
     * @throws VirtualizationException
     */
    VirtualFolderDefinition resolveVirtualFolderDefinition(Reference reference) throws VirtualizationException;
}

==> alfresco-repository-25.4.0.2-sources.jar: org/alfresco/repo/virtual/store/VirtualFolderDefinitionResolver.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.virtual.store;

import org.alfresco.repo.virtual.VirtualizationException;
import org.alfresco.repo.virtual.ref.Reference;
import org.alfresco.repo.virtual.template.VirtualFolderDefinition;

/**
 * A {@link Reference} based {@link VirtualFolderDefinition} resolver.<br>
 *
 * @author Bogdan Horje
 */
public interface VirtualFolderDefinitionResolver
{
    /**
     * @param reference
     * @return the {@link VirtualFolderDefinition} of the given {@link Reference} considering inner paths
     * @throws VirtualizationException
     */
    VirtualFolderDefinition resolveVirtualFolderDefinition(Reference reference) throws VirtualizationException;
}
